package com.goldenwater.gx.service;

import java.util.List;

import com.goldenwater.gx.domain.GxExchangeUnit;

/**
 * 数据交换单位Service接口
 */
public interface IGxExchangeUnitService {
    public GxExchangeUnit selectGxExchangeUnitById(Long id);

    public List<GxExchangeUnit> selectGxExchangeUnitList(GxExchangeUnit unit);

    public int insertGxExchangeUnit(GxExchangeUnit unit);

    public int updateGxExchangeUnit(GxExchangeUnit unit);

    public int deleteGxExchangeUnitByIds(Long[] ids);

    public int deleteGxExchangeUnitById(Long id);

    public Integer selectMaxOrderNum();
}
